@@ -9,7 +9,7 @@
     Released under the GNU Public Licence, Version 2.
 */
 
-#define VERSION "2.4.8"
+#define VERSION "2.4.10"
 
 #include "ksymoops.h"
 #include <ctype.h>
@@ -646,7 +646,7 @@ void read_symbol_sources(const OPTIONS *options)
     if (ss_ksyms_modules) {
 	expand_objects(options);
 	for (i = 0; i < ss_objects; ++i)
-	    read_object(ss_object[i]->source, i);
+	    read_object(ss_object[i]->source, i, options);
     }
     else if (options->objects)
 	printf("No modules in ksyms, skipping objects\n");
